# Sample Library (arylibrary)
A small demo library 

### Installation
```
pip install arylibrary
```

### Get started
How to multiply one number by another with this lib:

```Python
from arylibrary import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)


# Call the addition method
adder = Addition(10)

result = adder.add(10)

```